@@ -45,14 +45,17 @@ if (php_sapi_name() != 'cli') {
 }
 
 foreach ($config as $optname => $optval) {
-    if ($optval != ini_get($optname) && @ini_set($optname, $optval) === false) {
-        die("ERROR: Wrong '$optname' option value and it wasn't possible to set it to required value ($optval).\n"
-            ."Check your PHP configuration (including php_admin_flag).");
+    $ini_optval = filter_var(ini_get($optname), FILTER_VALIDATE_BOOLEAN);
+    if ($optval != $ini_optval && @ini_set($optname, $optval) === false) {
+        $error = "ERROR: Wrong '$optname' option value and it wasn't possible to set it to required value ($optval).\n"
+            . "Check your PHP configuration (including php_admin_flag).";
+        if (defined('STDERR')) fwrite(STDERR, $error); else echo $error;
+        exit(1);
     }
 }
 
 // framework constants
-define('RCUBE_VERSION', '0.9-beta');
+define('RCUBE_VERSION', '0.9.3');
 define('RCUBE_CHARSET', 'UTF-8');
 
 if (!defined('RCUBE_LIB_DIR')) {
@@ -81,6 +84,13 @@ if (extension_loaded('mbstring')) {
     @mb_regex_encoding(RCUBE_CHARSET);
 }
 
+// make sure the lib directory is in the include_path
+$rcube_include_path = realpath(RCUBE_LIB_DIR . '..');
+$sep = PATH_SEPARATOR;
+if (!preg_match("!(^|$sep)$rcube_include_path($sep|\$)!", ini_get('include_path'))) {
+    set_include_path(ini_get('include_path') . PATH_SEPARATOR . $rcube_include_path);
+}
+
 // Register autoloader
 spl_autoload_register('rcube_autoload');
 
